@@ -1,3 +1,11 @@
+# Load R files during development
+if(F) {
+  warning("in pbmcmapply: disable these lines before publishing package!")
+  source("R/progressBar.R")
+  source("R/txtProgressBarETA.R")
+  source("R/utils.R")
+}
+
 pbmcmapply <- function(FUN, ..., MoreArgs = NULL, mc.style = "ETA", mc.substyle = NA,
                        mc.cores =getOption("mc.cores", 2L),
                        ignore.interactive = getOption("ignore.interactive", F)) {
@@ -22,21 +30,41 @@ pbmcmapply <- function(FUN, ..., MoreArgs = NULL, mc.style = "ETA", mc.substyle
     return(mcmapply(FUN, ..., MoreArgs = MoreArgs, mc.cores = mc.cores))
   }
 
+  # If running in Windows, mc.cores must be 1
+  .verifyOSMulticoreSupport(mc.cores, "mc.cores > 1 is not supported on Windows due to limitation of mc*apply() functions.")
+
   progressFifo <- .establishFifo(tempfile())
   on.exit(close(progressFifo), add = T)
 
   progressMonitor <- futureCall(function(FUN, ..., MoreArgs, mc.cores) {
-    tryCatch(result <- mcmapply(function(...) {
+    # Get results
+    result <- mcmapply(function(...) {
       res <- FUN(...)
       writeBin(1L, progressFifo)
       return(res)
-    }, ..., MoreArgs = MoreArgs, mc.cores = mc.cores))
+    }, ..., MoreArgs = MoreArgs, mc.cores = mc.cores)
+
+    # Check if any error was triggered
+    if (any(grepl("Error in FUN(...)", result))) {
+      # Warn the progress monitor if there's an error
+      writeBin(-1L, progressFifo)
+    }
+
+    # Close the FIFO connection
+    close(progressFifo)
 
     return(result)
   }, globals = list(progressFifo = progressFifo), args = list(FUN, ..., MoreArgs = MoreArgs, mc.cores = mc.cores))
 
-  invisible(.updateProgress(length, progressFifo, mc.style, mc.substyle))
+  hasErrorInProgress <- .updateProgress(length, progressFifo, mc.style, mc.substyle)
 
   # Retrieve the result from the future
-  return(value(progressMonitor))
+  results <- value(progressMonitor)
+
+  # Check if errors happened in the future
+  if (hasErrorInProgress) {
+    warning("scheduled cores encountered errors in user code")
+  }
+
+  return(results)
 }
